@@ -85,7 +85,7 @@ void PredicateParse_initLexer( const char *s, yyscan_t scanner );
 void PredicateParse_mainParse( const char *_code );
 
 
-#line 89 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:339  */
+#line 89 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -105,8 +105,8 @@ void PredicateParse_mainParse( const char *_code );
 
 /* In a future release of Bison, this section will be replaced
    by #include "predicate_parser.h".  */
-#ifndef YY_SOLID_USR_SRC_PORTS_KF5_SOLID_KF5_SOLID_5_39_0_1_I686_BUILD_SRC_SOLID_PREDICATE_PARSER_H_INCLUDED
-# define YY_SOLID_USR_SRC_PORTS_KF5_SOLID_KF5_SOLID_5_39_0_1_I686_BUILD_SRC_SOLID_PREDICATE_PARSER_H_INCLUDED
+#ifndef YY_SOLID_USR_SRC_PORTS_KF5_SOLID_KF5_SOLID_5_43_0_1_X86_64_BUILD_SRC_SOLID_PREDICATE_PARSER_H_INCLUDED
+# define YY_SOLID_USR_SRC_PORTS_KF5_SOLID_KF5_SOLID_5_43_0_1_X86_64_BUILD_SRC_SOLID_PREDICATE_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -122,7 +122,7 @@ extern int Soliddebug;
 typedef void *yyscan_t;
 #endif
 
-#line 126 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:355  */
+#line 126 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:355  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -155,7 +155,7 @@ union YYSTYPE
      char *name;
      void *ptr;
 
-#line 159 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:355  */
+#line 159 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -167,11 +167,11 @@ typedef union YYSTYPE YYSTYPE;
 
 int Solidparse (yyscan_t scanner);
 
-#endif /* !YY_SOLID_USR_SRC_PORTS_KF5_SOLID_KF5_SOLID_5_39_0_1_I686_BUILD_SRC_SOLID_PREDICATE_PARSER_H_INCLUDED  */
+#endif /* !YY_SOLID_USR_SRC_PORTS_KF5_SOLID_KF5_SOLID_5_43_0_1_X86_64_BUILD_SRC_SOLID_PREDICATE_PARSER_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 175 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:358  */
+#line 175 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1006,25 +1006,25 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t scanner)
           case 20: /* predicate  */
 #line 55 "devices/predicate_parser.y" /* yacc.c:1257  */
       { PredicateParse_destroy( ((*yyvaluep).ptr) ); }
-#line 1010 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
+#line 1010 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
         break;
 
     case 21: /* predicate_atom  */
 #line 56 "devices/predicate_parser.y" /* yacc.c:1257  */
       { PredicateParse_destroy( ((*yyvaluep).ptr) ); }
-#line 1016 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
+#line 1016 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
         break;
 
     case 22: /* predicate_or  */
 #line 57 "devices/predicate_parser.y" /* yacc.c:1257  */
       { PredicateParse_destroy( ((*yyvaluep).ptr) ); }
-#line 1022 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
+#line 1022 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
         break;
 
     case 23: /* predicate_and  */
 #line 58 "devices/predicate_parser.y" /* yacc.c:1257  */
       { PredicateParse_destroy( ((*yyvaluep).ptr) ); }
-#line 1028 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
+#line 1028 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1257  */
         break;
 
 
@@ -1292,107 +1292,107 @@ yyreduce:
         case 2:
 #line 67 "devices/predicate_parser.y" /* yacc.c:1646  */
     { PredicateParse_setResult( (yyvsp[0].ptr) ); (yyval.ptr) = (yyvsp[0].ptr); }
-#line 1296 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1296 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 3:
 #line 68 "devices/predicate_parser.y" /* yacc.c:1646  */
     { PredicateParse_setResult( (yyvsp[-1].ptr) ); (yyval.ptr) = (yyvsp[-1].ptr); }
-#line 1302 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1302 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 4:
 #line 69 "devices/predicate_parser.y" /* yacc.c:1646  */
     { PredicateParse_setResult( (yyvsp[-1].ptr) ); (yyval.ptr) = (yyvsp[-1].ptr); }
-#line 1308 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1308 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 5:
 #line 71 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newAtom( (yyvsp[-4].name), (yyvsp[-2].name), (yyvsp[0].ptr) ); }
-#line 1314 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1314 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 6:
 #line 72 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newMaskAtom( (yyvsp[-4].name), (yyvsp[-2].name), (yyvsp[0].ptr) ); }
-#line 1320 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1320 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 7:
 #line 73 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newIsAtom( (yyvsp[0].name) ); }
-#line 1326 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1326 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 8:
 #line 75 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newOr( (yyvsp[-2].ptr), (yyvsp[0].ptr) ); }
-#line 1332 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1332 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 9:
 #line 77 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newAnd( (yyvsp[-2].ptr), (yyvsp[0].ptr) ); }
-#line 1338 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1338 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 10:
 #line 79 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newStringValue( (yyvsp[0].name) ); }
-#line 1344 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1344 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 11:
 #line 80 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newBoolValue( (yyvsp[0].valb) ); }
-#line 1350 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1350 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 12:
 #line 81 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newNumValue( (yyvsp[0].vali) ); }
-#line 1356 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1356 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 13:
 #line 82 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newDoubleValue( (yyvsp[0].vald) ); }
-#line 1362 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1362 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 14:
 #line 83 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = (yyvsp[0].ptr); }
-#line 1368 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1368 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 15:
 #line 85 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = (yyvsp[-2].ptr); }
-#line 1374 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1374 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 16:
 #line 87 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newEmptyStringListValue(); }
-#line 1380 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1380 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 17:
 #line 88 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_newStringListValue( (yyvsp[0].ptr) ); }
-#line 1386 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1386 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
   case 18:
 #line 89 "devices/predicate_parser.y" /* yacc.c:1646  */
     { (yyval.ptr) = PredicateParse_appendStringListValue( (yyvsp[-2].name), (yyvsp[0].ptr) ); }
-#line 1392 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1392 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
     break;
 
 
-#line 1396 "/usr/src/ports/kf5-solid/kf5-solid-5.39.0-1.i686/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
+#line 1396 "/usr/src/ports/kf5-solid/kf5-solid-5.43.0-1.x86_64/build/src/solid/predicate_parser.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
